@@ -1,7 +1,7 @@
 package Dist::Zilla::PluginBundle::Milla;
 
 use strict;
-use version; our $VERSION = version->declare('v1.0.18');
+use version; our $VERSION = version->declare('v1.0.19');
 
 use Dist::Milla;
 use Moose;
@@ -64,6 +64,9 @@ sub configure {
         # Set no_index to sensible directories
         [ 'MetaNoIndex', { directory => [ qw( t xt inc share eg examples ) ] } ],
 
+        # experimental dist metadata
+        [ 'StaticInstall', { mode => 'auto' } ],
+
         # cpanfile -> META.json
         [ 'Prereqs::FromCPANfile' ],
         [ $self->installer ],
